@@ -1,9 +1,9 @@
 from marketools.stock import *
 from marketools.wallet import Wallet
-from marketools.simulator import simulator
+from marketools.simulator import simulator, Simulator
 from marketools.analysis import *
 
 
-__pdoc__ = {}
+__pdoc__ = dict()
 __pdoc__['extra_print'] = False
 __pdoc__['wallet'] = False
